@@ -13,9 +13,14 @@
 #ifndef __ALIST_H__
 #define __ALIST_H__
 
+/* POSIX */
 #include <sys/types.h>
-#include "compat.h"
-#include "common.h"
+#if HAVE_STDINT_H
+#include <stdint.h>
+#endif
+/* gnulib/POSIX */
+#include <stdbool.h>
+/* common */
 #include "iterator.h"
 
 typedef struct _AList AList;
@@ -38,5 +43,9 @@ void *alist_set(AList *list, uint32_t index, void *data);
 void **alist_to_array(AList *list);
 void **alist_to_null_terminated_array(AList *list);
 void alist_trim_to_size(AList *list);
+bool alist_is_empty(AList *list);
+void *alist_remove_last(AList *list);
+void *alist_get_last(AList *list);
+void alist_iterate(AList *list, IteratorFunc iterator_func);
 
 #endif
