@@ -13,8 +13,10 @@
 #ifndef __MAP_H__
 #define __MAP_H__
 
-#include <sys/types.h>
-#include "compat.h"
+/* POSIX */
+#if HAVE_STDINT_H
+#include <stdint.h>
+#endif
 
 typedef int32_t (*CompareFunc)(const void *, const void *);
 
