@@ -13,22 +13,6 @@
 #ifndef __COMMON_H__
 #define __COMMON_H__
 
-typedef int common_bool;		/* like gboolean */
-#undef bool
-#define bool common_bool
-
-#ifndef TRUE
-#define TRUE		1
-#endif
-
-#ifndef FALSE
-#define FALSE		0
-#endif
-
-#ifndef NULL
-#define NULL		0
-#endif
-
 #ifndef MIN
 #define MIN(a,b)	( ((a)<(b)) ? (a):(b) )
 #endif
