@@ -13,9 +13,10 @@
 #ifndef __ERROR_H__
 #define __ERROR_H__
 
+/* C89 */
 #include <stdarg.h>
 #include <errno.h>		/* for errno below */
-#include "common.h"
+#include <stddef.h>
 
 extern void (*program_termination_hook)(void);
 
