@@ -13,9 +13,11 @@
 #ifndef __HMAP_H__
 #define __HMAP_H__
 
-#include <sys/types.h>
-#include "compat.h"
-#include "common.h"
+/* POSIX */
+#if HAVE_STDINT_H
+#include <stdint.h>
+#endif
+/* common */
 #include "collections.h"
 #include "iterator.h"
 
