@@ -10,10 +10,14 @@
  * details.
  */
 
-#include <config.h>
-#include <sys/types.h>
+/* POSIX/gnulib */
+#include <stdbool.h>
+/* POSIX */
+#if HAVE_STDINT_H
+#include <stdint.h>
+#endif
+/* common */
 #include "common.h"
-#include "compat.h"
 
 bool parse_int8(const char *instr, int8_t *outint);
 bool parse_int16(const char *instr, int16_t *outint);
