@@ -10,23 +10,67 @@
  * details.
  */
 
+#if HAVE_CONFIG_H
 #include <config.h>
-
+#endif
+/* As recommended by autoconf for AC_HEADER_DIRENT */
+#if HAVE_DIRENT_H
+# include <dirent.h>
+# define NAMLEN(dirent) strlen((dirent)->d_name)
+#else
+# define dirent direct
+# define NAMLEN(dirent) (dirent)->d_namlen
+# if HAVE_SYS_NDIR_H
+#  include <sys/ndir.h>
+# endif
+# if HAVE_SYS_DIR_H
+#  include <sys/dir.h>
+# endif
+# if HAVE_NDIR_H
+#  include <ndir.h>
+# endif
+#endif
+/* As recommended by autoconf for AC_HEADER_SYS_WAIT */
 #include <sys/types.h>
-#include <sys/stat.h>
-#include <sys/wait.h>
-#include <time.h>
-#include <dirent.h>
-#include <fcntl.h>
+#if HAVE_SYS_WAIT_H
+# include <sys/wait.h>
+#endif
+#ifndef WEXITSTATUS
+# define WEXITSTATUS(stat_val) ((unsigned)(stat_val) >> 8)
+#endif
+#ifndef WIFEXITED
+# define WIFEXITED(stat_val) (((stat_val) & 255) == 0)
+#endif
+/* As recommended by autoconf for AC_HEADER_SYS_TIME */
+#if TIME_WITH_SYS_TIME
+# include <sys/time.h>
+# include <time.h>
+#else
+# if HAVE_SYS_TIME_H
+#  include <sys/time.h>
+# else
+#  include <time.h>
+# endif
+#endif
+/* POSIX */
+#if HAVE_UNISTD_H
 #include <unistd.h>
+#endif
+#if HAVE_FCNTL_H
+#include <fcntl.h>
+#endif
+#include <sys/stat.h>
+/* C89 */
 #include <stdio.h>
 #include <stdlib.h>
 #include <errno.h>
-#include "getline.h"		/* compat */
-#include "strbuf.h"
-#include "common.h"
-#include "error.h"
+/* gnulib */
+#include <getline.h>
+#include <xalloc.h>
+/* common */
 #include "memory.h"
+#include "strbuf.h"
+#include "error.h"
 #include "string-utils.h"
 #include "llist.h"
 
@@ -37,9 +81,8 @@
 bool
 file_exists(const char *file)
 {
-	struct stat statbuf;
-	return (lstat(file, &statbuf) != -1);
-//	return access(file, F_OK) == 0;
+	struct stat64 statbuf;
+	return (lstat64(file, &statbuf) != -1);
 }
 
 /**
@@ -213,8 +256,12 @@ read_directory(const char *dir)
 	while ((ep = readdir(dp)) != NULL)
 		llist_add(files, xstrdup(ep->d_name));
 
+#if CLOSEDIR_VOID
+    	closedir(dp);
+#else
 	if (closedir(dp) == -1)
 		return NULL;
+#endif
 
 	return files;
 }
