@@ -13,8 +13,11 @@
 #ifndef __ITERATOR_H__
 #define __ITERATOR_H__
 
+/* POSIX */
 #include <sys/types.h>
-#include "compat.h"
+/* POSIX/gnulib */
+#include <stdbool.h>
+/* common */
 #include "common.h"
 
 typedef void (*IteratorFunc)(void *);
