@@ -13,16 +13,20 @@
 #ifndef __MEMORY_H__
 #define __MEMORY_H__
 
-#include <config.h>
-#include <stdlib.h>
+/* C89 */
+#include <stddef.h>
 #include <string.h>
+/* gnulib */
+#include <xalloc.h>
 
 #define memclear(mem, size)	memset((mem), 0, (size))
 
 char *xasprintf(const char *format, ...);
+/*
 void *xmalloc(size_t size);
 void *xrealloc(void *mem, size_t size);
 char *xstrdup(const char *str);
+*/
 
 extern inline void *
 xmalloc_clear(size_t size)
