@@ -13,9 +13,13 @@
 #ifndef __STRBUF_H__
 #define __STRBUF_H__
 
-#include <stdarg.h>
+/* POSIX */
 #include <sys/types.h>
-#include "compat.h"
+#if HAVE_STDINT_H
+#include <stdint.h>
+#endif
+/* C89 */
+#include <stdarg.h>
 
 /**
  * A buffer holding any characters of any length, even null-bytes.
