@@ -12,10 +12,11 @@
 
 #ifndef __TMAP_H__
 #define __TMAP_H__
-
-#include <sys/types.h>
-#include "compat.h"
-#include "common.h"
+/* POSIX */
+#if HAVE_STDINT_H
+#include <stdint.h>
+#endif
+/* common */
 #include "collections.h"
 #include "iterator.h"
 
